import { LucideIcon } from 'lucide-react';
import { Pet } from '../types/Pet';
import { isActionActive, formatResourceName, getResourceFromAction } from '../utils/petUtils';

const colorClassMap = {
  amber: 'bg-amber-900/30 hover:bg-amber-800/50 border-amber-500/50',
  emerald: 'bg-emerald-900/30 hover:bg-emerald-800/50 border-emerald-500/50',
  red: 'bg-red-900/30 hover:bg-red-800/50 border-red-500/50',
  green: 'bg-green-900/30 hover:bg-green-800/50 border-green-500/50',
  blue: 'bg-blue-900/30 hover:bg-blue-800/50 border-blue-500/50',
  purple: 'bg-purple-900/30 hover:bg-purple-800/50 border-purple-500/50',
} as const;

const activeColorClassMap = {
  amber: 'bg-amber-700/50 border-amber-400',
  emerald: 'bg-emerald-700/50 border-emerald-400',
  red: 'bg-red-700/50 border-red-400',
  green: 'bg-green-700/50 border-green-400',
  blue: 'bg-blue-700/50 border-blue-400',
  purple: 'bg-purple-700/50 border-purple-400',
} as const;

const getActionVerb = (actionType: 'gather' | 'explore' | 'battle'): string => {
  const verbs = {
    gather: 'Gathering',
    explore: 'Exploring',
    battle: 'Battling',
  };
  return verbs[actionType];
};

type ButtonColor = keyof typeof colorClassMap;

interface ActionResourceButtonProps {
  pet: Pet;
  icon: LucideIcon;
  label: string;
  actionType: 'gather' | 'explore' | 'battle';
  color: ButtonColor;
  onActionClick: () => void;
  onActionComplete: (updatedPet: Pet) => void;
}

export default function ActionResourceButton({
  pet,
  icon: Icon,
  label,
  actionType,
  color,
  onActionClick
}: ActionResourceButtonProps) {
  const isActive = isActionActive(pet.petGatherAction, actionType);
  const currentResource = getResourceFromAction(pet.petGatherAction);

  const getButtonText = () => {
    if (!isActive) return label;

    if (actionType === 'explore' && pet.petGatherAction === 'EXPLORE') {
      return 'Exploring';
    }
    if (actionType === 'battle' && pet.petGatherAction === 'BATTLE') {
      return 'Battling';
    }
    if (currentResource) {
      return `${getActionVerb(actionType)} ${formatResourceName(currentResource)}`;
    }
    return label;
  };

  return (
    <button
      onClick={onActionClick}
      className={`flex items-center justify-center space-x-2
        ${isActive ? activeColorClassMap[color] : colorClassMap[color]}
        border-2 rounded-lg p-4
        transition-all duration-300 transform hover:scale-105 w-full`}
    >
      <Icon className="w-6 h-6" />
      <span>{getButtonText()}</span>
    </button>
  );
}
