import { putPetCollectResources } from '../services/api/api';
import { PetActionGathered } from '../types/PetAction';
import { Pet } from '../types/Pet';

interface CollectResourcesButtonProps {
  petId: string;
  resources: PetActionGathered[];
  onCollect: () => void;
  onPetUpdate: (pet: Pet) => void;
}

export default function CollectResourcesButton({ petId, resources, onCollect, onPetUpdate }: CollectResourcesButtonProps) {
  const hasResources = Object.values(resources).length > 0;

  if (!hasResources) return null;

  const handleCollect = async () => {
    try {
      const updatedPet = await putPetCollectResources(petId);
      onPetUpdate(updatedPet);
      onCollect();
    } catch (error) {
      console.error('Failed to collect resources:', error);
    }
  };

  return (
    <button
      onClick={handleCollect}
      className="flex flex-col items-center justify-center
        bg-green-900/30 hover:bg-green-800/50
        border-2 border-green-500/50 rounded-lg p-4
        transition-all duration-300 transform hover:scale-105 w-full mt-2"
    >
      <span className="font-bold mb-1">Collect:</span>
      {resources.map((item, index) => (
        <span key={index}>
          {item.gameItem
            ? item.gameItem.name
            : `${item.resource} x${item.amount}`
          }
        </span>
      ))}
    </button>
  );
}
