import { AxiosError } from 'axios';
import { ApiError } from './types';

export class ApiErrorHandler {
  static handle(error: AxiosError): ApiError {
    if (error.response) {
      // Server responded with a status code outside of 2xx range
      return {
        message: error.response.data?.message || 'Server error occurred',
        code: 'SERVER_ERROR',
        status: error.response.status,
        details: error.response.data,
      };
    } else if (error.request) {
      // Request was made but no response received
      return {
        message: 'No response received from server',
        code: 'NETWORK_ERROR',
        status: 0,
        details: {
          request: error.request,
        },
      };
    } else {
      // Error occurred while setting up the request
      return {
        message: error.message || 'An error occurred while making the request',
        code: 'REQUEST_SETUP_ERROR',
        status: 0,
        details: {
          config: error.config,
        },
      };
    }
  }

  static isNetworkError(error: ApiError): boolean {
    return error.code === 'NETWORK_ERROR';
  }

  static isTimeoutError(error: ApiError): boolean {
    return error.message.toLowerCase().includes('timeout');
  }

  static isServerError(error: ApiError): boolean {
    return error.status >= 500;
  }

  static isClientError(error: ApiError): boolean {
    return error.status >= 400 && error.status < 500;
  }
}